"use strict";
exports.__esModule = true;
exports.decode = exports.encode = void 0;
var DICTIONARY = 'ABCDEFGHJKLMNOPQRSTUVWXYZabcdefhijkmnopqrstuvwxyz23456789';
var DICTIONARY_LENGTH = BigInt(DICTIONARY.length);
var SHARECODE_PATTERN = /CSGO(-?[\w]{5}){5}$/;
function bytesToHex(bytes) {
    return Array.from(bytes, function (byte) {
        return ('0' + (byte & 0xff).toString(16)).slice(-2);
    }).join('');
}
function bytesToBigInt(bytes) {
    var hex = bytesToHex(bytes);
    return BigInt("0x" + hex);
}
function stringToByteArray(str) {
    var bytes = [];
    for (var i = 0; i < str.length; i += 2) {
        bytes.push(parseInt(str.slice(i, i + 2), 16));
    }
    return bytes;
}
function int16ToBytes(number) {
    return [(number & 0x0000ff00) >> 8, number & 0x000000ff];
}
var encode = function (_a) {
    var matchId = _a.matchId, reservationId = _a.reservationId, tvPort = _a.tvPort;
    var matchBytes = stringToByteArray(matchId.toString(16)).reverse();
    var reservationBytes = stringToByteArray(reservationId.toString(16)).reverse();
    var tvBytes = int16ToBytes(tvPort).reverse();
    var bytes = Array.prototype.concat(matchBytes, reservationBytes, tvBytes);
    var hex = bytesToHex(bytes);
    var total = BigInt("0x" + hex);
    var c = '';
    var rem = BigInt(0);
    for (var i = 0; i < 25; i++) {
        rem = total % DICTIONARY_LENGTH;
        c += DICTIONARY[Number(rem)];
        total = total / DICTIONARY_LENGTH;
    }
    return "CSGO-" + c.substr(0, 5) + "-" + c.substr(5, 5) + "-" + c.substr(10, 5) + "-" + c.substr(15, 5) + "-" + c.substr(20, 5);
};
exports.encode = encode;
var decode = function (shareCode) {
    if (!shareCode.match(SHARECODE_PATTERN)) {
        throw new Error('Invalid share code');
    }
    shareCode = shareCode.replace(/CSGO|-/g, '');
    var chars = Array.from(shareCode).reverse();
    var big = BigInt(0);
    for (var i = 0; i < chars.length; i++) {
        big = big * DICTIONARY_LENGTH + BigInt(DICTIONARY.indexOf(chars[i]));
    }
    var str = big.toString(16).padStart(36, '0');
    var bytes = stringToByteArray(str);
    return {
        matchId: bytesToBigInt(bytes.slice(0, 8).reverse()),
        reservationId: bytesToBigInt(bytes.slice(8, 16).reverse()),
        tvPort: Number(bytesToBigInt(bytes.slice(16, 18).reverse()))
    };
};
exports.decode = decode;
//# sourceMappingURL=index.js.map